@@ -206,6 +206,53 @@ class TestTimestreamLoader_UnitTests:
         mock_session.assert_expectations()
         mock_client.assert_expectations()
 
+    @pytest.mark.unit
+    def test_private_load_empty_dimension(self):
+        # Test insert with empty dimension
+        expected_capture_time = '1609459200000'
+        expected_records = [{
+            'MeasureName': 'valid',
+            'MeasureValue': '1.0',
+            'Dimensions': [],
+            'Time': expected_capture_time
+        }]
+
+        mock_client = MockApi()
+        mock_client.on(
+            'write_records',
+            DatabaseName='test',
+            TableName='test',
+            CommonAttributes={
+                'Dimensions': [],
+                'MeasureValueType': 'DOUBLE',
+                'Version': int(expected_capture_time)
+            },
+            Records=expected_records
+        ).return_val(None)
+        mock_session = self.get_mock_session(mock_client)
+
+        loader = TimestreamLoader(
+            'test',
+            'test',
+            mock_session,
+            current_time_ms=int(expected_capture_time)
+        )
+        result = loader._TimestreamLoader__load(
+            data=[{
+                'valid': 1.0,
+                'empty_dimension': '',
+                'time': int(expected_capture_time)
+            }],
+            capture_time=datetime(2021, 1, 1, 0, 0, 0, 0, pytz.UTC),
+            upsert=True
+        )
+        assert type(result) == TimestreamLoadResult
+        assert len(result.accepted_records) == 1
+        assert result.accepted_records[0].measure_name == 'valid'
+        assert len(result.rejected_records) == 0
+        mock_session.assert_expectations()
+        mock_client.assert_expectations()
+
     @pytest.mark.unit
     def test_write_insert_records(self):
         # Set expectations
@@ -480,6 +527,53 @@ class TestTimestreamLoader_UnitTests:
         }, False, True, False)
         assert len(records) == 0
 
+    @pytest.mark.unit
+    def test_parse_item_empty_dimension(self):
+        mock_session = self.get_mock_session()
+        loader = TimestreamLoader('test', 'test', mock_session)
+        mock_session.assert_expectations()
+
+        # Test parse insert item
+        expected_dimensions = TimestreamDimensions({
+            'string': 'dimension'
+        })
+        records = loader._TimestreamLoader__parse_item({
+            'integer': 10,
+            'float': 20.0,
+            'list': [10, 20.0],
+            'string': 'dimension',
+            'empty_dimension': '',
+            'none': None
+        }, False, False, False)
+        assert len(records) == 3
+        assert str(records[0])
+
+        record = records[0]
+        assert record and type(record) == TimestreamRecord
+        assert record.measure_name == 'integer'
+        assert record.measure_value == 10.0
+        assert record.mstime == None
+        assert record.time == None
+        assert record.dimensions == expected_dimensions
+        assert record.dimensions.get_dimension('string') == 'dimension'
+        assert str(record.dimensions)
+
+        record = records[1]
+        assert record and type(record) == TimestreamRecord
+        assert record.measure_name == 'float'
+        assert record.measure_value == 20.0
+        assert record.mstime == None
+        assert record.time == None
+        assert record.dimensions == expected_dimensions
+
+        record = records[2]
+        assert record and type(record) == TimestreamRecord
+        assert record.measure_name == 'list'
+        assert record.measure_value == 2.0
+        assert record.mstime == None
+        assert record.time == None
+        assert record.dimensions == expected_dimensions
+
     @pytest.mark.unit
     def test_does_database_exist(self):
         # Set expectations
