@@ -28,7 +28,7 @@ def batch_records(
     logger: logging.Logger = None
 ) -> List[Batch]:
     logger = logger or get_logger()
-    if not min_common_dimensions:
+    if min_common_dimensions == 0:
         return dimensionless_batch(records, max_batch_size)
 
     batches, remaining = [], records
