@@ -140,7 +140,8 @@ class TimestreamLoader(TimestreamReader):
         batches = batch_records(
             result.accepted_records,
             max_batch_size=max_batch_size,
-            min_common_dimensions=min_common_dimensions
+            min_common_dimensions=min_common_dimensions,
+            logger=self._logger
         )
         assert isinstance(batches, list) and len(batches) > 0, 'Batches must be a non-empty list'
         assert all(len(b.records) > 0 for b in batches), "Not all batches have records (shouldn't be possible)"
